# -*- coding: utf-8 -*-
"""
-----------------------------------------------------
Copyright © Arthur Guiot 2018. All rights reserved
-----------------------------------------------------

/core/public/model.py defines the 'model' method that
will be used to generate a model object from pre
trained graphs

"""

def model(files, method="tensorflow"):
	return [0, method, files]
